#
# spec file for package kak-lsp
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kak-lsp
Version:        15.0.0
Release:        1.1
Summary:        Language Server Protocol client for Kakoune
License:        (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR BSL-1.0 OR MIT) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR Apache-2.0 WITH LLVM-exception OR MIT) AND (Apache-2.0 OR MIT OR Zlib) AND (Apache-2.0 OR MIT OR MPL-2.0) AND (MIT OR Unlicense) AND (Apache-2.0 OR Zlib OR MIT) AND MIT AND Zlib AND Unlicense
URL:            https://github.com/kak-lsp/kak-lsp
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  zstd

%description
kak-lsp is a Language Server Protocol client for Kakoune written in Rust.

%prep
%autosetup -a1

%build
%{cargo_build} --all-features

%install
%{cargo_install} --all-features
mkdir -p %{buildroot}%{_datadir}/%{name}/{examples,rc}
install -Dm644 %{name}.toml %{buildroot}%{_datadir}/%{name}/examples/
install -Dm644 rc/lsp.kak %{buildroot}%{_datadir}/%{name}/rc/

%files
%defattr(-,root,root,-)
%license UNLICENSE COPYING MIT
%doc     README.asciidoc CHANGELOG.md
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/examples
%dir %{_datadir}/%{name}/rc
%{_datadir}/%{name}/*

%{_bindir}/kak-lsp

%changelog
* Wed Nov 22 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 15.0.0:
  * Additions:
  - Support multiple language servers per filetype (#17).
  - The `kak-lsp.toml` format for specifying language servers has changed. The old format is still supported (#686).
  - `lsp-goto-document-symbol` learned to show a preview of the jump target.
  - Default configuration for PureScript and Scala.
  * Fixes:
  - A regression broke resolving completion item documentation when cycling through completion candidates, which has been fixed (#674).
  - New command `lsp-declaration`, implementing `textDocument/declaration`.
- cargo_config is now part of vendored tarball
* Tue Oct 31 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update _service file
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Sun Feb 19 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Updates to version 14.2.0:
  * Additions:
  - Default configuration for CMake.
  - If there are no code actions in the main selection, lsp-code-actions will show code actions from anywhere on a selected line, to make it easier to perform quick-fixes.
  - If requested by the language server, kak-lsp will recursively watch the entire root directory for file changes and forward them to the server via workspace/didChangeWatchedFiles (#649).
  - kak-lsp now asks the server to cancel stale requests (#666).
  - lsp-did-change is async again, which can improve performance (#667).
  - kak-lsp is published to crates.io for easy installation (#660).
  * Fixes:
  - Fix race conditions when spinning up a new server in "kak-lsp --request" (#654), and in "lsp-hover-buffer" (#664).
  - Send inlay hints and semantic tokens only after buffer changes (#663).
- Use zstd compression for vendored dep tarball
* Sat Nov 12 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 14.1.0:
  * Additions:
  - Default language server for protobuf.
  - Added support for `codeAction/resolve`, which allows to use code
    actions sent by Deno for example.
  - The recommended mappings have been augmented by new command
    `lsp-diagnostic-object` to jump to next/previous diagnostics.
  - `lsp-auto-signature-help-enable` now shows an info box by default,
    and formats the active parameter in a bold font.
  - `lsp-definition` and friends now select the symbol name instead of merely
    placing the cursor at symbol start. Same for `lsp-find-error`.
  - `lsp-highlight-references` now selects all references in the current buffer.
  - New `lsp-inlay-code-lenses-enable` command allows to render code
    lenses as virtual text (#623).
  - The support for `filterText` in completions no longer depends on an
    out-of-tree Kakoune feature.
  * Fixes:
  - Fix lags due to `rust-analyzer` sending a ton of progress reports.
  - `lsp-rename` will now write hidden buffers that are affected by the rename,
    to give the language server and other external tools a more consistent
    view of affected files.
  - Suppress "language server not initialized" errors that originate from hooks.
  - Fix a glitch when a line has both a code lens and an inline diagnostic.
  - When talking to servers that don't support UTF-8 byte-offsets, `kak-lsp`
    now adheres to the LSP specification by treating column-offsets
    as UTF-16 Code Units instead of Unicode Code Points.
* Sun Sep 25 2022 socvirnyl.estela@gmail.com
- Update to version 14.0.0:
  * Update changelog for release
  * lsp-goto-document-symbol: map to s instead of <c-o>
  * test: work around "unconfigured filetype" error in tests
  * test: remove unnecessary code for macOS-specific tests
  * Advertise some more LSP capabilities
  * capabilities: minor consistency change
  * clippy
  * lsp-goto-document-symbol: support nested symbols
  * lsp-capabilities: also advertise more commands based on textDocument/documentSymbols
* Tue May 17 2022 socvirnyl.estela@gmail.com
- Update to version 12.2.1:
  * v12.2.1
  * Update changelog for release
  * Test code lens from haskell-language-server
  * lsp-code-lens: pass correct args to lsp-perform-code-lens
  * start new cycle
  * v12.2.0
  * Update changelog for release
  * README: clarify "cargo install" behavior and kak-lsp.toml creation when using plug.kak
  * README: remove misleading warning
  * lsp-hover: limit to 20 lines via lsp_hover_max_lines
* Wed Apr  6 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for kak-lsp (12.1.0)
